/*
 * This file is part of sharing-vkontakte Burlak I.L.
 *
 * Copyright (C) 2008-2009 Nokia Corporation. All rights reserved.
 *
 * This maemo code example is licensed under a MIT-style license,
 * that can be found in the file called "COPYING" in the root
 * directory.
 *
 */

#include <stdio.h>
#include <glib.h>
#include <osso-log.h>
#include <conicconnection.h>
#include "validate.h"
#include "libvkontakte_interface.h"

/**
 * test:
 * @account: #SharingAccount to be tested
 * @con: Connection used
 * @dead_mans_switch: Turn to %FALSE at least every 30 seconds.
 *
 * Test if #SharingAccount is valid.
 *
 * Returns: #SharingPluginInterfaceTestAccountResult
 */
SharingPluginInterfaceAccountValidateResult validate (SharingAccount* account,
    ConIcConnection* con, gboolean *cont, gboolean* dead_mans_switch)
{
    SharingPluginInterfaceAccountValidateResult ret =
        SHARING_ACCOUNT_VALIDATE_SUCCESS;
    
    gchar* account_name = sharing_account_get_username (account);

    if(!libvk_init(con, account_name)){
        ret = SHARING_ACCOUNT_VALIDATE_ERROR_UNKNOWN;
    } else {
        if(libvk_testConnection()){
            // get and save account settings
            if (!libvk_get_settings(account)){
                ret = SHARING_ACCOUNT_VALIDATE_ERROR_UNKNOWN;
            }
        } else {
           ret = SHARING_ACCOUNT_VALIDATE_ERROR_UNKNOWN;
        }
        libvk_uninit (account_name);
    }

    return ret;
}
